@@ -198,8 +198,8 @@ class Underwriter(object):
         import aggregate
         s = []
         s.append(f'underwriter        {self.name}')
-        s.append(f'knowledge          {len(self._knowledge)} programs')
         s.append(f'version            {aggregate.__version__}')
+        s.append(f'knowledge          {len(self._knowledge)} programs')
         s.append(f'update             {self.update}')
         for k in ['log2', 'update', 'debug']:
             s.append(f'{k:<19s}{getattr(self, k)}')
@@ -216,8 +216,8 @@ class Underwriter(object):
         s.append( '')
         s.append( 'help')
         s.append( 'build.knowledge    list of all programs')
-        s.append( 'build.qlist(pat)   list programs matching pattern')
-        s.append( 'build.show(name)   build and display name')
+        s.append( 'build.qshow(pat)   show programs matching pattern')
+        s.append( 'build.show(pat)    build and display matching pattern')
         return '\n'.join(s)
 
     # def _repr_html_(self):
@@ -286,6 +286,11 @@ class Underwriter(object):
     def knowledge(self):
         return self._knowledge.sort_index()[['program', 'spec']]
 
+    def test_suite(self):
+        f = self.default_dir / 'test_suite.agg'
+        txt = f.read_text(encoding='utf-8')
+        return txt
+
     def write(self, portfolio_program, log2=0, bs=0, update=None, **kwargs):
         """
         Write a natural language program. Write carries out the following steps.
@@ -746,18 +751,28 @@ class Underwriter(object):
         df_out.index.name = 'index'
         return df_out
 
-    def qshow(self, regex):
+    def qlist(self, regex):
         """
         Wrapper for show to just list elements in knowledge that match ``regex``.
-
-        Either returns a dataframe or prints the dataframe.
-
+        Returns a dataframe.
         """
         return self.show(regex, kind='', plot=False, describe=False, return_df=True)
 
-    def qlist(self, regex):
-        qd(self.show(regex, kind='', plot=False, describe=False),
-           line_width=160, max_colwidth=60, justify='left')
+    def qshow(self, regex):
+        """
+        Wrapper for show to just show (display) elements in knowledge that match ``regex``.
+        No reutrn value.
+        """
+        def ff(x):
+            fs = '{x:120s}'
+            return fs.format(x=x)
+        bit = self.show(regex, kind='', plot=False, describe=False)[['program']]
+        bit['program'] = bit['program'].str.replace(r' note\{[^}]+\}', '').str.replace('  +', ' ') #, flags=re.MULTILINE)
+        # bit['program'] = bit['program'].str.replace(' ( +)', ' ') #, flags=re.MULTILINE)
+        # bit['program'] = bit['program'].str.replace(r' note\{[^}]+\}$|  *', ' '   ) #, flags=re.MULTILINE)
+        qd(bit,
+           line_width=160, max_colwidth=130, col_space=15, justify='left',
+           max_rows=200, formatters={'program': ff})
 
     def show(self, regex, kind='', plot=True, describe=True, logger_level=30, return_df=False):
         """
@@ -881,4 +896,4 @@ class Underwriter(object):
 # self = dbuild = None
 logger_level(30)
 build = Underwriter(databases='test_suite', update=True, debug=False, log2=16)
-debug_build = Underwriter(name='Debug', update=True, debug=True, log2=13)
+debug_build = Underwriter(name='Debug', update=True, debug=True, log2=16)
